aboutsummaryrefslogtreecommitdiff
path: root/map.c
diff options
context:
space:
mode:
Diffstat (limited to 'map.c')
-rw-r--r--map.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/map.c b/map.c
index 3a8ef8f..f83269f 100644
--- a/map.c
+++ b/map.c
@@ -94,7 +94,7 @@ Map rbt_maze_map(size_t width, size_t height, unsigned int seed) {
return map;
}
-void draw_map(Map map, int width, int height, Position player_pos) {
+void draw_map(Map map, int width, int height, Position start) {
// Draw field
char c; // The char for the current tile
for (int i = 0; i < height; i++) {
@@ -121,9 +121,9 @@ void draw_map(Map map, int width, int height, Position player_pos) {
}
}
- // Draw the player
- attron(COLOR_PAIR(PLAYER_COLOR));
- mvaddch(player_pos.y + DRAW_MAP_OFFSET_Y, player_pos.x + DRAW_MAP_OFFSET_X, PLAYER_CHAR);
- attroff(COLOR_PAIR(PLAYER_COLOR));
+ // Draw the start
+ attron(COLOR_PAIR(START_COLOR));
+ mvaddch(start.y + DRAW_MAP_OFFSET_Y, start.x + DRAW_MAP_OFFSET_X, START_CHAR);
+ attroff(COLOR_PAIR(START_COLOR));
}